@@ -30,47 +30,44 @@
 #' @return A `sf` object.
 #'
 #' @family geo functions
-#' @seealso
 #'
 #' @examples
-#' library(tidyr)
 #' library(starschemar)
-#' library(sf)
 #'
-#' gms <- geomultistar(ms = ms_mrs, geodimension = "where") %>%
+#' gms <- geomultistar(ms = ms_mrs, geodimension = "where") |>
 #'   define_geoattribute(
 #'     attribute = "city",
 #'     from_layer = usa_cities,
 #'     by = c("city" = "city", "state" = "state")
-#'   )  %>%
+#'   )  |>
 #'   define_geoattribute(
 #'     attribute = "state",
 #'     from_layer = usa_states,
 #'     by = c("state" = "state")
-#'   ) %>%
+#'   ) |>
 #'   define_geoattribute(attribute = "region",
-#'                       from_attribute = "state") %>%
+#'                       from_attribute = "state") |>
 #'   define_geoattribute(attribute = "all_where",
 #'                       from_layer = usa_nation)
 #'
-#' gdq <- dimensional_query(gms) %>%
+#' gdq <- dimensional_query(gms) |>
 #'   select_dimension(name = "where",
-#'                    attributes = c("state", "city")) %>%
+#'                    attributes = c("state", "city")) |>
 #'   select_dimension(name = "when",
-#'                    attributes = c("when_happened_year", "when_happened_week")) %>%
+#'                    attributes = c("when_happened_year", "when_happened_week")) |>
 #'   select_fact(
 #'     name = "mrs_age",
 #'     measures = c("n_deaths")
-#'   ) %>%
+#'   ) |>
 #'   select_fact(name = "mrs_cause",
-#'               measures = c("pneumonia_and_influenza_deaths", "other_deaths")) %>%
-#'   filter_dimension(name = "when", when_happened_week <= "03") %>%
+#'               measures = c("pneumonia_and_influenza_deaths", "other_deaths")) |>
+#'   filter_dimension(name = "when", when_happened_week <= "03") |>
 #'   filter_dimension(name = "where", state == "MA")
 #'
-#' sf <- gdq %>%
+#' sf <- gdq |>
 #'   run_geoquery()
 #'
-#' sfw <- gdq %>%
+#' sfw <- gdq |>
 #'   run_geoquery(wider = TRUE)
 #'
 #' @export
@@ -123,16 +120,16 @@ run_geoquery.dimensional_query <-
       l <- widen_flat_table(ft, pk, measures)
       ft <- l$sf
     }
-    ft <- dplyr::left_join(ft, geodim, by = pk) %>%
+    ft <- dplyr::left_join(ft, geodim, by = pk) |>
       sf::st_as_sf()
 
     if (wider) {
       l$sf <- ft
       l
     } else {
-      ft <- ft %>%
-        dplyr::select(tidyselect::all_of(columns)) %>%
-        dplyr::group_by_at(columns) %>%
+      ft <- ft |>
+        dplyr::select(tidyselect::all_of(columns)) |>
+        dplyr::group_by_at(columns) |>
         dplyr::summarize(.groups = "drop")
     }
   }
